@@ -8,9 +8,7 @@ from .options import ConverterOptions
 try:
     from .extensions.color_converter_nim import ColorConverterNim
 except Exception as e:
-    ColorConverterNim = unsupported_extension(
-        "color_converter_nim.ColorConverterNim", e
-    )
+    ColorConverterNim = unsupported_extension("color_converter_nim.ColorConverterNim", e)
 
 try:
     from .extensions.grayscale_converter_nim import GrayscaleConverterNim
